==========
Changelog
==========

This document records all notable changes to `HTTPie <https://httpie.org>`_.
This project adheres to `Semantic Versioning <https://semver.org/>`_.

1.3.0 (2020-05-20)

**Added**

* Checking whether project already exists on readthedocs

**Fixed**

* bump-version SNAPSHOT handling strongly improved

**Dependencies**

* requests==2.23.0 added

**Deprecated**

1.3.0 (2020-05-20)

**Added**

* bump-version now supports SNAPSHOTS
* documentation about 4 portlet prompts
* new COOKIETEMPLE docs css

**Fixed**

* Tests GHW names

**Dependencies**

**Deprecated**

1.2.1 (2020-05-03)

**Added**

* Refactored docs into common files

**Fixed**

**Dependencies**

**Deprecated**

1.2.0 (2020-05-03)

**Added**

* QUBE linting workflow for all templates
* PR to master from development only WF
* custom COOKIETEMPLE css

**Fixed**

* setup.py development status
* max width for docs for all templates
* PyPi badge is now green

**Dependencies**

* flake 3.7.9 -> 3.8.1

**Deprecated**


1.1.0 (2020-05-03)
---------------------

**Added**

* The correct version tag :)

**Fixed**

* Readthedocs width is now

**Dependencies**

**Deprecated**

1.0.0 (2020-05-03)
------------------

**Added**

* Created the project using COOKIETEMPLE
* Added create, list, info, bump-version, lint based on COOKIETEPLE
* Added cli-java template
* Added lib-java template
* Added gui-java template
* Added service-java template
* Added portlet-groovy template

**Fixed**

**Dependencies**

**Deprecated**
